@@ -92,11 +92,12 @@ def AnalyzeSpeaker(speaker,form):
     logger.info("Process %s" % str(os.getpid()))
     out = speaker.analyze(form)
     logger.info("Got %s lines for %s" % (str(len(out)),str(speaker)))
+    wanted = form.get_wanted_fields()
     with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
-        f.write("\t".join(out[0].keys()))
+        f.write("\t".join(wanted))
         f.write("\n")
         for l in out:
-            f.write("\t".join(map(str,l.values())))
+            f.write("\t".join([ str(l[x]) for x in wanted])
             f.write("\n")
     logger.info("Completed analysis of %s" % str(speaker))
     return out
